@@ -140,7 +140,12 @@ export class HeSetupModel {
                         "APPLIANCE_PASSWORD",
                         "ISCSI_PASSWORD",
                         "ISCSI_DISCOVER_PASSWORD",
-                        "ROOTPWD"
+                        "ROOTPWD",
+                        "he_appliance_password",
+                        "he_admin_password",
+                        "he_iscsi_password",
+                        "he_iscsi_discover_password",
+                        "ansible_ssh_pass"
                     ],
                     type: types.STRING,
                     showInReview: false,
@@ -296,7 +301,8 @@ export class HeSetupModel {
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
-                    required: false
+                    required: false,
+                    sensitive: true
                 },
                 iSCSIDiscoverUser: {
                     name: "iSCSIDiscoverUser",
@@ -320,7 +326,8 @@ export class HeSetupModel {
                     showInReview: false,
                     uiStage: "Storage",
                     useInAnswerFile: false,
-                    required: false
+                    required: false,
+                    sensitive: true
                 },
                 iSCSIPortalIPAddress: {
                     name: "iSCSIPortalIPAddress",
@@ -807,7 +814,8 @@ export class HeSetupModel {
                     reviewOrder: 70,
                     uiStage: "VM",
                     useInAnswerFile: false,
-                    required: true
+                    required: true,
+                    sensitive: true
                 },
                 rootSshPubkey: {
                     name: "rootSshPubkey",
@@ -984,7 +992,8 @@ export class HeSetupModel {
                     reviewOrder: 0,
                     uiStage: "Engine",
                     useInAnswerFile: false,
-                    required: true
+                    required: true,
+                    sensitive: true
                 },
                 enableLibgfapi: {
                     name: "enableLibgfapi",
